/**
 * Various of endpoint the CoinMarketCap API.
 *
 * @property {object} crypto - Endpoints related to cryptocurrency data.
 * @property {object} dex - Endpoints related to decentralized exchanges.
 * @property {object} cex - Endpoints related to centralized exchanges.
 * @property {object} metric - Endpoints related to various metrics and statistics.
 * @property {object} community - Endpoints related to community data and interactions.
 * @property {object} misc - Miscellaneous endpoints that do not fit into other categories.
 */
declare const endpoints: {
    crypto: {
        map: string;
        metadata: string;
        listings: string;
        listingsNew: string;
        listingsHistorical: string;
        quotes: string;
        quotesHistorical: string;
        quotesHistoricalV3: string;
        marketPairs: string;
        ohlcv: string;
        ohlcvHistorical: string;
        performance: string;
        categories: string;
        category: string;
        airdrops: string;
        airdrop: string;
        trending: string;
        mostVisited: string;
        gainersLosers: string;
    };
    dex: {
        map: string;
        listings: string;
        metadata: string;
        pairs: string;
        quotes: string;
        ohlcv: string;
        ohlcvHistorical: string;
        trades: string;
    };
    cex: {
        map: string;
        metadata: string;
        listings: string;
        quotes: string;
        quotesHistorical: string;
        pairs: string;
        assets: string;
    };
    metric: {
        quotes: string;
        quotesHistorical: string;
        index: string;
        indexHistorical: string;
        fearAndGreed: string;
        fearAndGreedHistorical: string;
    };
    community: {
        news: string;
        top: string;
        latest: string;
        comments: string;
        trendingTopic: string;
        trendingToken: string;
    };
    misc: {
        fiat: string;
        priceConversion: string;
    };
};
export default endpoints;
