"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CmcErrorCode = void 0;
/**
 * Enumeration of possible error codes returned by the CMC API.
 * @see {@link https://pro.coinmarketcap.com/api/v1#section/Errors-and-Rate-Limits | Error Response Codes}
 * @enum
 */
var CmcErrorCode;
(function (CmcErrorCode) {
    /** This API Key is invalid */
    CmcErrorCode[CmcErrorCode["ApikeyInvalid"] = 1001] = "ApikeyInvalid";
    /** API key missing */
    CmcErrorCode[CmcErrorCode["ApikeyMissing"] = 1002] = "ApikeyMissing";
    /**
     * Your API Key must be activated.
     * Please go to {@link https://pro.coinmarketcap.com/account/plan | CoinMarketCap Account Plan}
     */
    CmcErrorCode[CmcErrorCode["ApikeyPlanRequiresPayment"] = 1003] = "ApikeyPlanRequiresPayment";
    /** Your API Key's subscription plan has expired */
    CmcErrorCode[CmcErrorCode["ApikeyPlanPaymentExpired"] = 1004] = "ApikeyPlanPaymentExpired";
    /** An API Key is required for this call */
    CmcErrorCode[CmcErrorCode["ApikeyRequired"] = 1005] = "ApikeyRequired";
    /** Your API Key subscription plan doesn't support this endpoint */
    CmcErrorCode[CmcErrorCode["ApikeyPlanNotAuthorized"] = 1006] = "ApikeyPlanNotAuthorized";
    /** This API Key has been disabled. Please contact support */
    CmcErrorCode[CmcErrorCode["ApikeyDisable"] = 1007] = "ApikeyDisable";
    /** You've exceeded your API Key's HTTP request rate limit. Rate limits reset every minute */
    CmcErrorCode[CmcErrorCode["ApikeyPlanMinuteRateLimitReached"] = 1008] = "ApikeyPlanMinuteRateLimitReached";
    /** You've exceeded your API Key's daily rate limit */
    CmcErrorCode[CmcErrorCode["ApikeyPlanDailyRateLimitReached"] = 1009] = "ApikeyPlanDailyRateLimitReached";
    /** You've exceeded your API Key's monthly rate limit */
    CmcErrorCode[CmcErrorCode["ApikeyPlanMonthlyRateLimitReached"] = 1010] = "ApikeyPlanMonthlyRateLimitReached";
    /** You've hit an IP rate limit */
    CmcErrorCode[CmcErrorCode["IpRateLimitReached"] = 1011] = "IpRateLimitReached";
})(CmcErrorCode || (exports.CmcErrorCode = CmcErrorCode = {}));
//# sourceMappingURL=cmc-error-code.enum.js.map